#
# spec file for package spirv-llvm-translator
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2023, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   18
Name:           spirv-llvm-translator
Version:        18.1.3
Release:        1.1
Summary:        LLVM/SPIR-V Bi-Directional Translator library
License:        BSD-3-Clause
Group:          System/Libraries
URL:            https://github.com/KhronosGroup/SPIRV-LLVM-Translator
Source:         https://github.com/KhronosGroup/SPIRV-LLVM-Translator/archive/refs/tags/v%{version}.tar.gz#/SPIRV-LLVM-Translator-%{version}.tar.gz
Source101:      %{name}.rpmlintrc
BuildRequires:  cmake >= 3.3
BuildRequires:  gcc-c++
BuildRequires:  llvm%{sover}-devel
BuildRequires:  pkgconfig
BuildRequires:  spirv-headers
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(zlib)

%description
The LLVM/SPIR-V Bi-Directional Translator, a library and tool for translation
between LLVM IR and SPIR-V.

%package -n libLLVMSPIRVLib%{sover}
Summary:        LLVM/SPIR-V Bi-Directional Translator library
Group:          System/Libraries

%description -n libLLVMSPIRVLib%{sover}
The LLVM/SPIR-V Bi-Directional Translator, a library and tool for translation
between LLVM IR and SPIR-V.

%package -n libLLVMSPIRVLib-devel
Summary:        Development files for LLVM/SPIR-V Bi-Directional Translator library
Group:          Development/Languages/C and C++
Requires:       libLLVMSPIRVLib%{sover} = %{version}

%description -n libLLVMSPIRVLib-devel
The LLVM/SPIR-V Bi-Directional Translator, a library and tool for translation
between LLVM IR and SPIR-V.

This package provides headers and libraries required for building software using
the LLVM/SPIR-V Bi-Directional Translator library.

%prep
%setup -q -n SPIRV-LLVM-Translator-%{version}

%build
%cmake \
 -DLLVM_EXTERNAL_SPIRV_HEADERS_SOURCE_DIR=%{_prefix} \
 -DLLVM_SPIRV_BUILD_EXTERNAL=YES
%cmake_build

%install
%cmake_install

%post   -n libLLVMSPIRVLib%{sover} -p /sbin/ldconfig
%postun -n libLLVMSPIRVLib%{sover} -p /sbin/ldconfig

%files -n libLLVMSPIRVLib%{sover}
%license LICENSE.TXT
%doc README.md
%{_libdir}/libLLVMSPIRVLib.so.%{sover}*

%files -n libLLVMSPIRVLib-devel
%{_bindir}/llvm-spirv
%{_includedir}/LLVMSPIRVLib
%{_libdir}/libLLVMSPIRVLib.so
%{_libdir}/pkgconfig/LLVMSPIRVLib.pc

%changelog
* Sat Aug  3 2024 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 18.1.3.
  * Support for SPIR-V 1.6.
* Wed Jul  3 2024 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 18.1.2.
  * Various bug fixes.
- Drop Support-SPV_INTEL_maximum_registers-extension.patch since
  the issue was addressed upstream.
* Thu Mar 14 2024 Stefan Dirsch <sndirsch@suse.com>
- fixed rpmlintrc rule
* Thu Mar  7 2024 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 18.1.0.
  * Compatibility with LLVM 18.
- Add rpmlintrc: following the LLVM's new versioning scheme, this
  package not only has versions X.1.Y now, but the SO name is X.1.
  However, the minor version is always going to be 1, and there is
  no need to distinguish between minor versions, so we don't add it
  to the package name.
- Drop ca3ae0cc.patch that landed upstream.
- Add Support-SPV_INTEL_maximum_registers-extension.patch to revert
  change temporarily because the corresponding change in spirv-
  headers is not released yet.
* Tue Jan 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add ca3ae0cc.patch: Update LongConstantCompositeINTEL to
  LongCompositesINTEL capability after Headers change. Patch only
  applied when building against spirv-headers >= 1.6.1+sdk275.
* Thu Sep 28 2023 Stefan Dirsch <sndirsch@suse.com>
- back again to version 17.0.0, since meanwhile llvm17 is available ...
* Mon Sep 25 2023 Stefan Dirsch <sndirsch@suse.com>
- back to version 16.0.0, since there is no llvm17 available yet ...
* Tue Sep 19 2023 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 17.0.0.
  * Compatibility with LLVM 17.
- Drop Revert-Add-support-for-LLVM_LINK_LLVM_DYLIB.patch: the
  problematic change was reverted upstream.
- Drop Revert-added-translator-support-for-SPIRV_INTEL.patch: the
  corresponding change to spirv-headers has landed in the meantime.
* Wed Mar 22 2023 Aaron Puchert <aaronpuchert@alice-dsl.net>
- Update to version 16.0.0.
  * Compatibility with LLVM 16.
- Add Revert-Add-support-for-LLVM_LINK_LLVM_DYLIB.patch: while
  gh#KhronosGroup/SPIRV-LLVM-Translator#1543 claims to add support
  for LLVM_LINK_LLVM_DYLIB, it actually seems to break it.
- Add Revert-added-translator-support-for-SPIRV_INTEL.patch: while
  gh#KhronosGroup/SPIRV-LLVM-Translator#1632 has made it into this
  release, there is no release of spirv-headers containing the
  pendant gh#KhronosGroup/SPIRV-Headers#291 yet.
* Sun Jan 15 2023 Martin Hauke <mardnh@gmx.de>
- Initial package for spirv-llvm-translator, version 15.0.0
